@@ -16,7 +16,7 @@
 
 import unittest
 
-from google.cloud import translate
+from google.cloud import translate_v2
 
 
 class Config(object):
@@ -30,7 +30,7 @@ class Config(object):
 
 
 def setUpModule():
-    Config.CLIENT = translate.Client()
+    Config.CLIENT = translate_v2.Client()
 
 
 class TestTranslate(unittest.TestCase):
@@ -67,7 +67,10 @@ class TestTranslate(unittest.TestCase):
         self.assertEqual(translations[1]["translatedText"].lower(), "fünfzehn")
 
         self.assertEqual(translations[2]["detectedSourceLanguage"], "es")
-        self.assertEqual(translations[2]["translatedText"].lower(), "ich heiße jeff")
+        es_translation = translations[2]["translatedText"].lower()
+        self.assertTrue(
+            es_translation == "ich heiße jeff" or es_translation == "mein name ist jeff"
+        )
 
         self.assertEqual(translations[3]["detectedSourceLanguage"], "en")
         self.assertEqual(
